_**by Edgar Allan Poe**  
(published 1850)_

    

    THE symposium of the preceding evening had been a little too much for my nerves. I had a wretched headache, and was desperately drowsy. Instead of going out therefore to spend the evening as I had proposed, it occurred to me that I could not do a wiser thing than just eat a mouthful of supper and go immediately to bed.  
  
A light supper of course. I am exceedingly fond of Welsh rabbit. More than a pound at once, however, may not at all times be advisable. Still, there can be no material objection to two. And really between two and three, there is merely a single unit of difference. I ventured, perhaps, upon four. My wife will have it five; -- but, clearly, she has confounded two very distinct affairs. The abstract number, five, I am willing to admit; but, concretely, it has reference to bottles of Brown Stout, without which, in the way of condiment, Welsh rabbit is to be eschewed.  
  
Having thus concluded a frugal meal, and donned my night-cap, with the serene hope of enjoying it till noon the next day, I placed my head upon the pillow, and, through the aid of a capital conscience, fell into a profound slumber forthwith.  
  
But when were the hopes of humanity fulfilled? I could not have completed my third snore when there came a furious ringing at the street-door bell, and then an impatient thumping at the knocker, which awakened me at once. In a minute afterward, and while I was still rubbing my eyes, my wife thrust in my face a note, from my old friend, Doctor Ponnonner. It ran thus:  
  
Come to me, by all means, my dear good friend, as soon as you receive this. Come and help us to rejoice. At last, by long persevering diplomacy, I have gained the assent of the Directors of the City Museum, to my examination of the Mummy -- you know the one I mean. I have permission to unswathe it and open it, if desirable. A few friends only will be present -- you, of course. The Mummy is now at my house, and we shall begin to unroll it at eleven to-night.  
  
Yours, ever, PONNONNER.  
  
By the time I had reached the "Ponnonner," it struck me that I was as wide awake as a man need be. I leaped out of bed in an ecstacy, overthrowing all in my way; dressed myself with a rapidity truly marvellous; and set off, at the top of my speed, for the doctor's.  
  
There I found a very eager company assembled. They had been awaiting me with much impatience; the Mummy was extended upon the dining-table; and the moment I entered its examination was commenced.  
  
It was one of a pair brought, several years previously, by Captain Arthur Sabretash, a cousin of Ponnonner's from a tomb near Eleithias, in the Lybian mountains, a considerable distance above Thebes on the Nile. The grottoes at this point, although less magnificent than the Theban sepulchres, are of higher interest, on account of affording more numerous illustrations of the private life of the Egyptians. The chamber from which our specimen was taken, was said to be very rich in such illustrations; the walls being completely covered with fresco paintings and bas-reliefs, while statues, vases, and Mosaic work of rich patterns, indicated the vast wealth of the deceased.  
  
The treasure had been deposited in the Museum precisely in the same condition in which Captain Sabretash had found it; -- that is to say, the coffin had not been disturbed. For eight years it had thus stood, subject only externally to public inspection. We had now, therefore, the complete Mummy at our disposal; and to those who are aware how very rarely the unransacked antique reaches our shores, it will be evident, at once that we had great reason to congratulate ourselves upon our good fortune.  
  
Approaching the table, I saw on it a large box, or case, nearly seven feet long, and perhaps three feet wide, by two feet and a half deep. It was oblong -- not coffin-shaped. The material was at first supposed to be the wood of the sycamore (platanus), but, upon cutting into it, we found it to be pasteboard, or, more properly, papier mache, composed of papyrus. It was thickly ornamented with paintings, representing funeral scenes, and other mournful subjects -- interspersed among which, in every variety of position, were certain series of hieroglyphical characters, intended, no doubt, for the name of the departed. By good luck, Mr. Gliddon formed one of our party; and he had no difficulty in translating the letters, which were simply phonetic, and represented the word Allamistakeo.  
  
We had some difficulty in getting this case open without injury; but having at length accomplished the task, we came to a second, coffin-shaped, and very considerably less in size than the exterior one, but resembling it precisely in every other respect. The interval between the two was filled with resin, which had, in some degree, defaced the colors of the interior box.  
  
Upon opening this latter (which we did quite easily), we arrived at a third case, also coffin-shaped, and varying from the second one in no particular, except in that of its material, which was cedar, and still emitted the peculiar and highly aromatic odor of that wood. Between the second and the third case there was no interval -- the one fitting accurately within the other.  
  
Removing the third case, we discovered and took out the body itself. We had expected to find it, as usual, enveloped in frequent rolls, or bandages, of linen; but, in place of these, we found a sort of sheath, made of papyrus, and coated with a layer of plaster, thickly gilt and painted. The paintings represented subjects connected with the various supposed duties of the soul, and its presentation to different divinities, with numerous identical human figures, intended, very probably, as portraits of the persons embalmed. Extending from head to foot was a columnar, or perpendicular, inscription, in phonetic hieroglyphics, giving again his name and titles, and the names and titles of his relations.  
  
Around the neck thus ensheathed, was a collar of cylindrical glass beads, diverse in color, and so arranged as to form images of deities, of the scarabaeus, etc, with the winged globe. Around the small of the waist was a similar collar or belt.  
  
Stripping off the papyrus, we found the flesh in excellent preservation, with no perceptible odor. The color was reddish. The skin was hard, smooth, and glossy. The teeth and hair were in good condition. The eyes (it seemed) had been removed, and glass ones substituted, which were very beautiful and wonderfully life-like, with the exception of somewhat too determined a stare. The fingers and the nails were brilliantly gilded.  
  
Mr. Gliddon was of opinion, from the redness of the epidermis, that the embalmment had been effected altogether by asphaltum; but, on scraping the surface with a steel instrument, and throwing into the fire some of the powder thus obtained, the flavor of camphor and other sweet-scented gums became apparent.  
  
We searched the corpse very carefully for the usual openings through which the entrails are extracted, but, to our surprise, we could discover none. No member of the party was at that period aware that entire or unopened mummies are not infrequently met. The brain it was customary to withdraw through the nose; the intestines through an incision in the side; the body was then shaved, washed, and salted; then laid aside for several weeks, when the operation of embalming, properly so called, began.  
  
As no trace of an opening could be found, Doctor Ponnonner was preparing his instruments for dissection, when I observed that it was then past two o'clock. Hereupon it was agreed to postpone the internal examination until the next evening; and we were about to separate for the present, when some one suggested an experiment or two with the Voltaic pile.  
  
The application of electricity to a mummy three or four thousand years old at the least, was an idea, if not very sage, still sufficiently original, and we all caught it at once. About one-tenth in earnest and nine-tenths in jest, we arranged a battery in the Doctor's study, and conveyed thither the Egyptian.  
  
It was only after much trouble that we succeeded in laying bare some portions of the temporal muscle which appeared of less stony rigidity than other parts of the frame, but which, as we had anticipated, of course, gave no indication of galvanic susceptibility when brought in contact with the wire. This, the first trial, indeed, seemed decisive, and, with a hearty laugh at our own absurdity, we were bidding each other good night, when my eyes, happening to fall upon those of the Mummy, were there immediately riveted in amazement. My brief glance, in fact, had sufficed to assure me that the orbs which we had all supposed to be glass, and which were originally noticeable for a certain wild stare, were now so far covered by the lids, that only a small portion of the tunica albuginea remained visible.  
  
With a shout I called attention to the fact, and it became immediately obvious to all.  
  
I cannot say that I was alarmed at the phenomenon, because "alarmed" is, in my case, not exactly the word. It is possible, however, that, but for the Brown Stout, I might have been a little nervous. As for the rest of the company, they really made no attempt at concealing the downright fright which possessed them. Doctor Ponnonner was a man to be pitied. Mr. Gliddon, by some peculiar process, rendered himself invisible. Mr. Silk Buckingham, I fancy, will scarcely be so bold as to deny that he made his way, upon all fours, under the table.  
  
After the first shock of astonishment, however, we resolved, as a matter of course, upon further experiment forthwith. Our operations were now directed against the great toe of the right foot. We made an incision over the outside of the exterior os sesamoideum pollicis pedis, and thus got at the root of the abductor muscle. Readjusting the battery, we now applied the fluid to the bisected nerves -- when, with a movement of exceeding life-likeness, the Mummy first drew up its right knee so as to bring it nearly in contact with the abdomen, and then, straightening the limb with inconceivable force, bestowed a kick upon Doctor Ponnonner, which had the effect of discharging that gentleman, like an arrow from a catapult, through a window into the street below.  
  
We rushed out en masse to bring in the mangled remains of the victim, but had the happiness to meet him upon the staircase, coming up in an unaccountable hurry, brimful of the most ardent philosophy, and more than ever impressed with the necessity of prosecuting our experiment with vigor and with zeal.  
  
It was by his advice, accordingly, that we made, upon the spot, a profound incision into the tip of the subject's nose, while the Doctor himself, laying violent hands upon it, pulled it into vehement contact with the wire.  
  
Morally and physically -- figuratively and literally -- was the effect electric. In the first place, the corpse opened its eyes and winked very rapidly for several minutes, as does Mr. Barnes in the pantomime, in the second place, it sneezed; in the third, it sat upon end; in the fourth, it shook its fist in Doctor Ponnonner's face; in the fifth, turning to Messieurs Gliddon and Buckingham, it addressed them, in very capital Egyptian, thus:  
  
"I must say, gentlemen, that I am as much surprised as I am mortified at your behaviour. Of Doctor Ponnonner nothing better was to be expected. He is a poor little fat fool who knows no better. I pity and forgive him. But you, Mr. Gliddon- and you, Silk -- who have travelled and resided in Egypt until one might imagine you to the manner born -- you, I say who have been so much among us that you speak Egyptian fully as well, I think, as you write your mother tongue -- you, whom I have always been led to regard as the firm friend of the mummies -- I really did anticipate more gentlemanly conduct from you. What am I to think of your standing quietly by and seeing me thus unhandsomely used? What am I to suppose by your permitting Tom, Dick, and Harry to strip me of my coffins, and my clothes, in this wretchedly cold climate? In what light (to come to the point) am I to regard your aiding and abetting that miserable little villain, Doctor Ponnonner, in pulling me by the nose?"  
  
It will be taken for granted, no doubt, that upon hearing this speech under the circumstances, we all either made for the door, or fell into violent hysterics, or went off in a general swoon. One of these three things was, I say, to be expected. Indeed each and all of these lines of conduct might have been very plausibly pursued. And, upon my word, I am at a loss to know how or why it was that we pursued neither the one nor the other. But, perhaps, the true reason is to be sought in the spirit of the age, which proceeds by the rule of contraries altogether, and is now usually admitted as the solution of every thing in the way of paradox and impossibility. Or, perhaps, after all, it was only the Mummy's exceedingly natural and matter-of-course air that divested his words of the terrible. However this may be, the facts are clear, and no member of our party betrayed any very particular trepidation, or seemed to consider that any thing had gone very especially wrong.  
  
For my part I was convinced it was all right, and merely stepped aside, out of the range of the Egyptian's fist. Doctor Ponnonner thrust his hands into his breeches' pockets, looked hard at the Mummy, and grew excessively red in the face. Mr. Glidden stroked his whiskers and drew up the collar of his shirt. Mr. Buckingham hung down his head, and put his right thumb into the left corner of his mouth.  
  
The Egyptian regarded him with a severe countenance for some minutes and at length, with a sneer, said:  
  
"Why don't you speak, Mr. Buckingham? Did you hear what I asked you, or not? Do take your thumb out of your mouth!"  
  
Mr. Buckingham, hereupon, gave a slight start, took his right thumb out of the left corner of his mouth, and, by way of indemnification inserted his left thumb in the right corner of the aperture above-mentioned.  
  
Not being able to get an answer from Mr. B., the figure turned peevishly to Mr. Gliddon, and, in a peremptory tone, demanded in general terms what we all meant.  
  
Mr. Gliddon replied at great length, in phonetics; and but for the deficiency of American printing-offices in hieroglyphical type, it would afford me much pleasure to record here, in the original, the whole of his very excellent speech.  
  
I may as well take this occasion to remark, that all the subsequent conversation in which the Mummy took a part, was carried on in primitive Egyptian, through the medium (so far as concerned myself and other untravelled members of the company) -- through the medium, I say, of Messieurs Gliddon and Buckingham, as interpreters. These gentlemen spoke the mother tongue of the Mummy with inimitable fluency and grace; but I could not help observing that (owing, no doubt, to the introduction of images entirely modern, and, of course, entirely novel to the stranger) the two travellers were reduced, occasionally, to the employment of sensible forms for the purpose of conveying a particular meaning. Mr. Gliddon, at one period, for example, could not make the Egyptian comprehend the term "politics," until he sketched upon the wall, with a bit of charcoal a little carbuncle-nosed gentleman, out at elbows, standing upon a stump, with his left leg drawn back, right arm thrown forward, with his fist shut, the eyes rolled up toward Heaven, and the mouth open at an angle of ninety degrees. Just in the same way Mr. Buckingham failed to convey the absolutely modern idea "wig," until (at Doctor Ponnonner's suggestion) he grew very pale in the face, and consented to take off his own.  
  
It will be readily understood that Mr. Gliddon's discourse turned chiefly upon the vast benefits accruing to science from the unrolling and disembowelling of mummies; apologizing, upon this score, for any disturbance that might have been occasioned him, in particular, the individual Mummy called Allamistakeo; and concluding with a mere hint (for it could scarcely be considered more) that, as these little matters were now explained, it might be as well to proceed with the investigation intended. Here Doctor Ponnonner made ready his instruments.  
  
In regard to the latter suggestions of the orator, it appears that Allamistakeo had certain scruples of conscience, the nature of which I did not distinctly learn; but he expressed himself satisfied with the apologies tendered, and, getting down from the table, shook hands with the company all round.  
  
When this ceremony was at an end, we immediately busied ourselves in repairing the damages which our subject had sustained from the scalpel. We sewed up the wound in his temple, bandaged his foot, and applied a square inch of black plaster to the tip of his nose.  
  
It was now observed that the Count (this was the title, it seems, of Allamistakeo) had a slight fit of shivering -- no doubt from the cold. The Doctor immediately repaired to his wardrobe, and soon returned with a black dress coat, made in Jennings' best manner, a pair of sky-blue plaid pantaloons with straps, a pink gingham chemise, a flapped vest of brocade, a white sack overcoat, a walking cane with a hook, a hat with no brim, patent-leather boots, straw-colored kid gloves, an eye-glass, a pair of whiskers, and a waterfall cravat. Owing to the disparity of size between the Count and the doctor (the proportion being as two to one), there was some little difficulty in adjusting these habiliments upon the person of the Egyptian; but when all was arranged, he might have been said to be dressed. Mr. Gliddon, therefore, gave him his arm, and led him to a comfortable chair by the fire, while the Doctor rang the bell upon the spot and ordered a supply of cigars and wine.  
  
The conversation soon grew animated. Much curiosity was, of course, expressed in regard to the somewhat remarkable fact of Allamistakeo's still remaining alive.  
  
"I should have thought," observed Mr. Buckingham, "that it is high time you were dead."  
  
"Why," replied the Count, very much astonished, "I am little more than seven hundred years old! My father lived a thousand, and was by no means in his dotage when he died."  
  
Here ensued a brisk series of questions and computations, by means of which it became evident that the antiquity of the Mummy had been grossly misjudged. It had been five thousand and fifty years and some months since he had been consigned to the catacombs at Eleithias.  
  
"But my remark," resumed Mr. Buckingham, "had no reference to your age at the period of interment (I am willing to grant, in fact, that you are still a young man), and my illusion was to the immensity of time during which, by your own showing, you must have been done up in asphaltum."  
  
"In what?" said the Count.  
  
"In asphaltum," persisted Mr. B.  
  
"Ah, yes; I have some faint notion of what you mean; it might be made to answer, no doubt -- but in my time we employed scarcely any thing else than the Bichloride of Mercury."  
  
"But what we are especially at a loss to understand," said Doctor Ponnonner, "is how it happens that, having been dead and buried in Egypt five thousand years ago, you are here to-day all alive and looking so delightfully well."  
  
"Had I been, as you say, dead," replied the Count, "it is more than probable that dead, I should still be; for I perceive you are yet in the infancy of Calvanism, and cannot accomplish with it what was a common thing among us in the old days. But the fact is, I fell into catalepsy, and it was considered by my best friends that I was either dead or should be; they accordingly embalmed me at once -- I presume you are aware of the chief principle of the embalming process?"  
  
"Why not altogether."  
  
"Why, I perceive -- a deplorable condition of ignorance! Well I cannot enter into details just now: but it is necessary to explain that to embalm (properly speaking), in Egypt, was to arrest indefinitely all the animal functions subjected to the process. I use the word 'animal' in its widest sense, as including the physical not more than the moral and vital being. I repeat that the leading principle of embalmment consisted, with us, in the immediately arresting, and holding in perpetual abeyance, all the animal functions subjected to the process. To be brief, in whatever condition the individual was, at the period of embalmment, in that condition he remained. Now, as it is my good fortune to be of the blood of the Scarabaeus, I was embalmed alive, as you see me at present."  
  
"The blood of the Scarabaeus!" exclaimed Doctor Ponnonner.  
  
"Yes. The Scarabaeus was the insignium or the 'arms,' of a very distinguished and very rare patrician family. To be 'of the blood of the Scarabaeus,' is merely to be one of that family of which the Scarabaeus is the insignium. I speak figuratively."  
  
"But what has this to do with you being alive?"  
  
"Why, it is the general custom in Egypt to deprive a corpse, before embalmment, of its bowels and brains; the race of the Scarabaei alone did not coincide with the custom. Had I not been a Scarabeus, therefore, I should have been without bowels and brains; and without either it is inconvenient to live."  
  
"I perceive that," said Mr. Buckingham, "and I presume that all the entire mummies that come to hand are of the race of Scarabaei."  
  
"Beyond doubt."  
  
"I thought," said Mr. Gliddon, very meekly, "that the Scarabaeus was one of the Egyptian gods."  
  
"One of the Egyptian what?" exclaimed the Mummy, starting to its feet.  
  
"Gods!" repeated the traveller.  
  
"Mr. Gliddon, I really am astonished to hear you talk in this style," said the Count, resuming his chair. "No nation upon the face of the earth has ever acknowledged more than one god. The Scarabaeus, the Ibis, etc., were with us (as similar creatures have been with others) the symbols, or media, through which we offered worship to the Creator too august to be more directly approached."  
  
There was here a pause. At length the colloquy was renewed by Doctor Ponnonner.  
  
"It is not improbable, then, from what you have explained," said he, "that among the catacombs near the Nile there may exist other mummies of the Scarabaeus tribe, in a condition of vitality?"  
  
"There can be no question of it," replied the Count; "all the Scarabaei embalmed accidentally while alive, are alive now. Even some of those purposely so embalmed, may have been overlooked by their executors, and still remain in the tomb."  
  
"Will you be kind enough to explain," I said, "what you mean by 'purposely so embalmed'?"  
  
"With great pleasure!" answered the Mummy, after surveying me leisurely through his eye-glass -- for it was the first time I had ventured to address him a direct question.  
  
"With great pleasure," he said. "The usual duration of man's life, in my time, was about eight hundred years. Few men died, unless by most extraordinary accident, before the age of six hundred; few lived longer than a decade of centuries; but eight were considered the natural term. After the discovery of the embalming principle, as I have already described it to you, it occurred to our philosophers that a laudable curiosity might be gratified, and, at the same time, the interests of science much advanced, by living this natural term in installments. In the case of history, indeed, experience demonstrated that something of this kind was indispensable. An historian, for example, having attained the age of five hundred, would write a book with great labor and then get himself carefully embalmed; leaving instructions to his executors pro tem., that they should cause him to be revivified after the lapse of a certain period -- say five or six hundred years. Resuming existence at the expiration of this time, he would invariably find his great work converted into a species of hap-hazard note-book -- that is to say, into a kind of literary arena for the conflicting guesses, riddles, and personal squabbles of whole herds of exasperated commentators. These guesses, etc., which passed under the name of annotations, or emendations, were found so completely to have enveloped, distorted, and overwhelmed the text, that the author had to go about with a lantern to discover his own book. When discovered, it was never worth the trouble of the search. After re-writing it throughout, it was regarded as the bounden duty of the historian to set himself to work immediately in correcting, from his own private knowledge and experience, the traditions of the day concerning the epoch at which he had originally lived. Now this process of re-scription and personal rectification, pursued by various individual sages from time to time, had the effect of preventing our history from degenerating into absolute fable."  
  
"I beg your pardon," said Doctor Ponnonner at this point, laying his hand gently upon the arm of the Egyptian -- "I beg your pardon, sir, but may I presume to interrupt you for one moment?"  
  
"By all means, sir," replied the Count, drawing up.  
  
"I merely wished to ask you a question," said the Doctor. "You mentioned the historian's personal correction of traditions respecting his own epoch. Pray, sir, upon an average what proportion of these Kabbala were usually found to be right?"  
  
"The Kabbala, as you properly term them, sir, were generally discovered to be precisely on a par with the facts recorded in the un-re-written histories themselves; -- that is to say, not one individual iota of either was ever known, under any circumstances, to be not totally and radically wrong."  
  
"But since it is quite clear," resumed the Doctor, "that at least five thousand years have elapsed since your entombment, I take it for granted that your histories at that period, if not your traditions were sufficiently explicit on that one topic of universal interest, the Creation, which took place, as I presume you are aware, only about ten centuries before."  
  
"Sir!" said the Count Allamistakeo.  
  
The Doctor repeated his remarks, but it was only after much additional explanation that the foreigner could be made to comprehend them. The latter at length said, hesitatingly:  
  
"The ideas you have suggested are to me, I confess, utterly novel. During my time I never knew any one to entertain so singular a fancy as that the universe (or this world if you will have it so) ever had a beginning at all. I remember once, and once only, hearing something remotely hinted, by a man of many speculations, concerning the origin of the human race; and by this individual, the very word Adam (or Red Earth), which you make use of, was employed. He employed it, however, in a generical sense, with reference to the spontaneous germination from rank soil (just as a thousand of the lower genera of creatures are germinated) -- the spontaneous germination, I say, of five vast hordes of men, simultaneously upspringing in five distinct and nearly equal divisions of the globe."  
  
Here, in general, the company shrugged their shoulders, and one or two of us touched our foreheads with a very significant air. Mr. Silk Buckingham, first glancing slightly at the occiput and then at the sinciput of Allamistakeo, spoke as follows:  
  
"The long duration of human life in your time, together with the occasional practice of passing it, as you have explained, in installments, must have had, indeed, a strong tendency to the general development and conglomeration of knowledge. I presume, therefore, that we are to attribute the marked inferiority of the old Egyptians in all particulars of science, when compared with the moderns, and more especially with the Yankees, altogether to the superior solidity of the Egyptian skull."  
  
"I confess again," replied the Count, with much suavity, "that I am somewhat at a loss to comprehend you; pray, to what particulars of science do you allude?"  
  
Here our whole party, joining voices, detailed, at great length, the assumptions of phrenology and the marvels of animal magnetism.  
  
Having heard us to an end, the Count proceeded to relate a few anecdotes, which rendered it evident that prototypes of Gall and Spurzheim had flourished and faded in Egypt so long ago as to have been nearly forgotten, and that the manoeuvres of Mesmer were really very contemptible tricks when put in collation with the positive miracles of the Theban savans, who created lice and a great many other similar things.  
  
I here asked the Count if his people were able to calculate eclipses. He smiled rather contemptuously, and said they were.  
  
This put me a little out, but I began to make other inquiries in regard to his astronomical knowledge, when a member of the company, who had never as yet opened his mouth, whispered in my ear, that for information on this head, I had better consult Ptolemy (whoever Ptolemy is), as well as one Plutarch de facie lunae.  
  
I then questioned the Mummy about burning-glasses and lenses, and, in general, about the manufacture of glass; but I had not made an end of my queries before the silent member again touched me quietly on the elbow, and begged me for God's sake to take a peep at Diodorus Siculus. As for the Count, he merely asked me, in the way of reply, if we moderns possessed any such microscopes as would enable us to cut cameos in the style of the Egyptians. While I was thinking how I should answer this question, little Doctor Ponnonner committed himself in a very extraordinary way.  
  
"Look at our architecture!" he exclaimed, greatly to the indignation of both the travellers, who pinched him black and blue to no purpose.  
  
"Look," he cried with enthusiasm, "at the Bowling-Green Fountain in New York! or if this be too vast a contemplation, regard for a moment the Capitol at Washington, D. C.!" -- and the good little medical man went on to detail very minutely, the proportions of the fabric to which he referred. He explained that the portico alone was adorned with no less than four and twenty columns, five feet in diameter, and ten feet apart.  
  
The Count said that he regretted not being able to remember, just at that moment, the precise dimensions of any one of the principal buildings of the city of Aznac, whose foundations were laid in the night of Time, but the ruins of which were still standing, at the epoch of his entombment, in a vast plain of sand to the westward of Thebes. He recollected, however, (talking of the porticoes,) that one affixed to an inferior palace in a kind of suburb called Carnac, consisted of a hundred and forty-four columns, thirty-seven feet in circumference, and twenty-five feet apart. The approach to this portico, from the Nile, was through an avenue two miles long, composed of sphynxes, statues, and obelisks, twenty, sixty, and a hundred feet in height. The palace itself (as well as he could remember) was, in one direction, two miles long, and might have been altogether about seven in circuit. Its walls were richly painted all over, within and without, with hieroglyphics. He would not pretend to assert that even fifty or sixty of the Doctor's Capitols might have been built within these walls, but he was by no means sure that two or three hundred of them might not have been squeezed in with some trouble. That palace at Carnac was an insignificant little building after all. He (the Count), however, could not conscientiously refuse to admit the ingenuity, magnificence, and superiority of the Fountain at the Bowling Green, as described by the Doctor. Nothing like it, he was forced to allow, had ever been seen in Egypt or elsewhere.  
  
I here asked the Count what he had to say to our railroads.  
  
"Nothing," he replied, "in particular." They were rather slight, rather ill-conceived, and clumsily put together. They could not be compared, of course, with the vast, level, direct, iron-grooved causeways upon which the Egyptians conveyed entire temples and solid obelisks of a hundred and fifty feet in altitude.  
  
I spoke of our gigantic mechanical forces.  
  
He agreed that we knew something in that way, but inquired how I should have gone to work in getting up the imposts on the lintels of even the little palace at Carnac.  
  
This question I concluded not to hear, and demanded if he had any idea of Artesian wells; but he simply raised his eyebrows; while Mr. Gliddon winked at me very hard and said, in a low tone, that one had been recently discovered by the engineers employed to bore for water in the Great Oasis.  
  
I then mentioned our steel; but the foreigner elevated his nose, and asked me if our steel could have executed the sharp carved work seen on the obelisks, and which was wrought altogether by edge-tools of copper.  
  
This disconcerted us so greatly that we thought it advisable to vary the attack to Metaphysics. We sent for a copy of a book called the "Dial," and read out of it a chapter or two about something that is not very clear, but which the Bostonians call the Great Movement of Progress.  
  
The Count merely said that Great Movements were awfully common things in his day, and as for Progress, it was at one time quite a nuisance, but it never progressed.  
  
We then spoke of the great beauty and importance of Democracy, and were at much trouble in impressing the Count with a due sense of the advantages we enjoyed in living where there was suffrage ad libitum, and no king.  
  
He listened with marked interest, and in fact seemed not a little amused. When we had done, he said that, a great while ago, there had occurred something of a very similar sort. Thirteen Egyptian provinces determined all at once to be free, and to set a magnificent example to the rest of mankind. They assembled their wise men, and concocted the most ingenious constitution it is possible to conceive. For a while they managed remarkably well; only their habit of bragging was prodigious. The thing ended, however, in the consolidation of the thirteen states, with some fifteen or twenty others, in the most odious and insupportable despotism that was ever heard of upon the face of the Earth.  
  
I asked what was the name of the usurping tyrant.  
  
As well as the Count could recollect, it was Mob.  
  
Not knowing what to say to this, I raised my voice, and deplored the Egyptian ignorance of steam.  
  
The Count looked at me with much astonishment, but made no answer. The silent gentleman, however, gave me a violent nudge in the ribs with his elbows -- told me I had sufficiently exposed myself for once -- and demanded if I was really such a fool as not to know that the modern steam-engine is derived from the invention of Hero, through Solomon de Caus.  
  
We were now in imminent danger of being discomfited; but, as good luck would have it, Doctor Ponnonner, having rallied, returned to our rescue, and inquired if the people of Egypt would seriously pretend to rival the moderns in the all- important particular of dress.  
  
The Count, at this, glanced downward to the straps of his pantaloons, and then taking hold of the end of one of his coat-tails, held it up close to his eyes for some minutes. Letting it fall, at last, his mouth extended itself very gradually from ear to ear; but I do not remember that he said any thing in the way of reply.  
  
Hereupon we recovered our spirits, and the Doctor, approaching the Mummy with great dignity, desired it to say candidly, upon its honor as a gentleman, if the Egyptians had comprehended, at any period, the manufacture of either Ponnonner's lozenges or Brandreth's pills.  
  
We looked, with profound anxiety, for an answer -- but in vain. It was not forthcoming. The Egyptian blushed and hung down his head. Never was triumph more consummate; never was defeat borne with so ill a grace. Indeed, I could not endure the spectacle of the poor Mummy's mortification. I reached my hat, bowed to him stiffly, and took leave.  
  
Upon getting home I found it past four o'clock, and went immediately to bed. It is now ten A.M. I have been up since seven, penning these memoranda for the benefit of my family and of mankind. The former I shall behold no more. My wife is a shrew. The truth is, I am heartily sick of this life and of the nineteenth century in general. I am convinced that every thing is going wrong. Besides, I am anxious to know who will be President in 2045. As soon, therefore, as I shave and swallow a cup of coffee, I shall just step over to Ponnonner's and get embalmed for a couple of hundred years.